@@ -6,7 +6,7 @@ Dancer::Plugin::Catmandu::OAI - OAI-PMH provider backed by a searchable Catmandu
 
 =cut
 
-our $VERSION = '0.0305';
+our $VERSION = '0.0306';
 
 use Catmandu::Sane;
 use Catmandu::Util qw(:is);
@@ -79,6 +79,7 @@ sub oai_provider {
     $setting->{granularity} //= "YYYY-MM-DDThh:mm:ssZ";
     $setting->{get_record_cql_pattern} //= '_id exact "%s"';
 
+    # TODO this was for backwards compatibility. Remove?
     if ($setting->{filter}) {
         $setting->{cql_filter} = delete $setting->{filter};
     }
@@ -472,9 +473,10 @@ TT
                 $cql_until = DateTime::Format::Strptime::strftime($pattern, parse_oai_datestamp($cql_until)) if $cql_until;
             }
 
-            push @cql, qq|($setting->{cql_filter})|                      if $setting->{cql_filter};
-            push @cql, qq|($set->{cql})|                                 if $set && $set->{cql};
-            push @cql, qq|($setting->{datestamp_field} >= "$cql_from")|  if $cql_from;
+            push @cql, qq|($setting->{cql_filter})| if $setting->{cql_filter};
+            push @cql, qq|($format->{cql})| if $format->{cql};
+            push @cql, qq|($set->{cql})| if $set && $set->{cql};
+            push @cql, qq|($setting->{datestamp_field} >= "$cql_from")| if $cql_from;
             push @cql, qq|($setting->{datestamp_field} <= "$cql_until")| if $cql_until;
             unless (@cql) {
                 push @cql, "(cql.allRecords)";
@@ -603,6 +605,7 @@ register_plugin;
                     schema: "http://www.openarchives.org/OAI/2.0/oai_dc.xsd"
                     metadataNamespace: "http://www.openarchives.org/OAI/2.0/oai_dc/"
                     template: views/oai_dc.tt
+                    cql: 'status exact public OR status exact deleted'
                     fix:
                       - publication_to_dc()
                 -
@@ -610,7 +613,7 @@ register_plugin;
                     schema: "http://www.loc.gov/standards/mods/v3/mods-3-0.xsd"
                     metadataNamespace: "http://www.loc.gov/mods/v3"
                     template: views/mods.tt
-                    filter: 'submissionstatus exact public'
+                    cql: 'status exact public'
                     fix:
                       - publication_to_mods()
             sets:
